Get a temporary filename, similar to tempfile, except that it always writes to a temporary folder named beastier.
Examples
get_beastier_tempfilename()
#> [1] "/github/home/.cache/beastier/file70e2967cb31"
get_beastier_tempfilename(pattern = "my_pattern_")
#> [1] "/github/home/.cache/beastier/my_pattern_70e5a4e031f"
get_beastier_tempfilename(fileext = ".ext")
#> [1] "/github/home/.cache/beastier/file70e160d1422.ext"