Get a temporary filename, similar to tempfile, except that it always writes to a temporary folder named beastier.
Examples
get_beastier_tempfilename()
#> [1] "/github/home/.cache/beastier/file6d077d4f2"
get_beastier_tempfilename(pattern = "my_pattern_")
#> [1] "/github/home/.cache/beastier/my_pattern_6d0413bddd5"
get_beastier_tempfilename(fileext = ".ext")
#> [1] "/github/home/.cache/beastier/file6d0128fc305.ext"