Get a temporary filename, similar to tempfile, except that it always writes to a temporary folder named beastier.
Examples
get_beastier_tempfilename()
#> [1] "/github/home/.cache/beastier/file66231715342"
get_beastier_tempfilename(pattern = "my_pattern_")
#> [1] "/github/home/.cache/beastier/my_pattern_6621bca8193"
get_beastier_tempfilename(fileext = ".ext")
#> [1] "/github/home/.cache/beastier/file662450e3ea5.ext"