Get a temporary filename, similar to tempfile, except that it always writes to a temporary folder named beastier.
Examples
get_beastier_tempfilename()
#> [1] "/github/home/.cache/beastier/file6af1fb624b7"
get_beastier_tempfilename(pattern = "my_pattern_")
#> [1] "/github/home/.cache/beastier/my_pattern_6af3c7bc1bc"
get_beastier_tempfilename(fileext = ".ext")
#> [1] "/github/home/.cache/beastier/file6af3ac689e3.ext"