Get a temporary filename, similar to tempfile, except that it always writes to a temporary folder named beastier.
Examples
get_beastier_tempfilename()
#> [1] "/github/home/.cache/beastier/file6745ab29ad6"
get_beastier_tempfilename(pattern = "my_pattern_")
#> [1] "/github/home/.cache/beastier/my_pattern_6744c75ca5b"
get_beastier_tempfilename(fileext = ".ext")
#> [1] "/github/home/.cache/beastier/file6741b57a55.ext"